==> kdevplatform-1.6.90.tar.xz: kdevplatform-1.6.90/plugins/testview/kdevtestview.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=Lets you see and run unit tests.
Comment[bs]=Omogućava da vidite i iztvršite testove jedinica
Comment[ca]=Us permet veure i executar proves unitàries.
Comment[ca@valencia]=Vos permet veure i executar proves unitàries.
Comment[da]=Lader dig se og køre unittest.
Comment[de]=Unit-Tests anzeigen und ausführen.
Comment[el]=Σας επιτρέπει να δείτε και να εκτελείτε unit tests.
Comment[es]=Le permite ver y ejecutar pruebas unitarias.
Comment[et]=Ühiktestide näitamine ja käivitamine.
Comment[fi]=Mahdollistaa yksikkötestien tarkastelemisen ja suorittamisen
Comment[fr]=Permet de voir et exécuter des tests unitaires.
Comment[gl]=Permite ver e executar probas unitarias.
Comment[hu]=Lehetővé teszi az egységtesztek megtekintését és futtatását.
Comment[it]=Ti permette di vedere ed eseguire i test d'unità.
Comment[kk]=Модуль сынағын қарап жегу мүмкіндігі.
Comment[nb]=Brukes til å se og kjøre enhetstester.
Comment[nl]=Laat u testen van eenheden zien en uitvoeren.
Comment[pl]=Pozwala tobie na obejrzenie i uruchomienie testów jednostkowych.
Comment[pt]=Permite-lhe ver e executar testes unitários.
Comment[pt_BR]=Permite-lhe ver e executar testes unitários.
Comment[ru]=Позволяет просматривать и запускать модульные тесты.
Comment[sk]=Umožní vám vidieť a spustiť unit testy.
Comment[sl]=Omogoča ogled in zagon preizkusov enot.
Comment[sv]=Låter dig titta på och köra enhetstester.
Comment[tr]=Birim testlerini görmenizi ve çalıştırmanızı sağlar.
Comment[uk]=Надає вам змогу переглядати і виконувати перевірки модулів.
Comment[x-test]=xxLets you see and run unit tests.xx
Comment[zh_CN]=让您查看并运行单元测试。
Comment[zh_TW]=讓您查看並執行單元測試。
Name=Unit Test View
Name[bs]=Pogled testa jedinica
Name[ca]=Vista de proves unitàries
Name[ca@valencia]=Vista de proves unitàries
Name[da]=Visning af unittests
Name[de]=Unittest-Ansicht
Name[el]=Προβολή unit test
Name[es]=Vista de la prueba unitaria
Name[et]=Ühiktestide vaade
Name[fi]=Yksikkötestinäkymä
Name[fr]=Affichage des tests unitaires
Name[gl]=Vista de probas unitarias
Name[hu]=Egységteszt nézet
Name[it]=Vista test d'unità
Name[kk]=Модульді сынау көрінісі
Name[nb]=Enhetstest-visning
Name[nl]=Weergave van test van eenheid
Name[pl]=Widok jednostkowego testu
Name[pt]=Área de Testes Unitários
Name[pt_BR]=Exibição de testes unitários
Name[ru]=Панель модульных тестов
Name[sk]=Pohľad unit testov
Name[sl]=Prikaz preizkusov enot
Name[sv]=Visning av enhetstester
Name[tr]=Birim Test Görünümü
Name[uk]=Перегляд перевірок модулів
Name[x-test]=xxUnit Test Viewxx
Name[zh_CN]=单元测试视图
Name[zh_TW]=單元測試檢視
GenericName=Unit Test View
GenericName[bs]=Pogled testa jedinica
GenericName[ca]=Vista de proves unitàries
GenericName[ca@valencia]=Vista de proves unitàries
GenericName[da]=Visning af unittests
GenericName[de]=Unittest-Ansicht
GenericName[el]=Προβολή unit test
GenericName[es]=Vista de la prueba unitaria
GenericName[et]=Ühiktestide vaade
GenericName[fi]=Yksikkötestinäkymä
GenericName[fr]=Affichage des tests unitaires
GenericName[gl]=Vista de probas unitarias
GenericName[hu]=Egységteszt nézet
GenericName[it]=Vista test d'unità
GenericName[kk]=Модульді сынау көрінісі
GenericName[nb]=Enhetstest-visning
GenericName[nl]=Weergave van test van eenheid
GenericName[pl]=Widok jednostkowego testu
GenericName[pt]=Área de Testes Unitários
GenericName[pt_BR]=Exibição de testes unitários
GenericName[ru]=Панель модульных тестов
GenericName[sk]=Pohľad unit testov
GenericName[sl]=Prikaz preizkusov enot
GenericName[sv]=Visning av enhetstester
GenericName[tr]=Birim Test Görünümü
GenericName[uk]=Перегляд перевірок модулів
GenericName[x-test]=xxUnit Test Viewxx
GenericName[zh_CN]=单元测试视图
GenericName[zh_TW]=單元測試檢視
Icon=preflight-verifier
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevtestview
X-KDE-PluginInfo-Name=kdevtestview
X-KDE-PluginInfo-Author=Miha Čančula
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Testing
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI

==> kdevplatform_1.7.0.orig.tar.xz: kdevplatform-1.7.0/plugins/testview/kdevtestview.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=Lets you see and run unit tests.
Comment[bs]=Omogućava da vidite i iztvršite testove jedinica
Comment[ca]=Us permet veure i executar proves unitàries.
Comment[ca@valencia]=Vos permet veure i executar proves unitàries.
Comment[da]=Lader dig se og køre enhedstester.
Comment[de]=Unit-Tests anzeigen und ausführen.
Comment[el]=Σας επιτρέπει να δείτε και να εκτελέσετε unit tests.
Comment[en_GB]=Lets you see and run unit tests.
Comment[es]=Le permite ver y ejecutar pruebas unitarias.
Comment[et]=Ühiktestide näitamine ja käivitamine.
Comment[fi]=Mahdollistaa yksikkötestien tarkastelemisen ja suorittamisen
Comment[fr]=Permet de voir et exécuter des tests unitaires.
Comment[gl]=Permite ver e executar probas unitarias.
Comment[hu]=Lehetővé teszi az egységtesztek megtekintését és futtatását.
Comment[it]=Ti permette di vedere ed eseguire i test d'unità.
Comment[kk]=Модуль сынағын қарап жегу мүмкіндігі.
Comment[nb]=Brukes til å se og kjøre enhetstester.
Comment[nl]=Laat u testen van eenheden zien en uitvoeren.
Comment[pl]=Pozwala tobie na obejrzenie i uruchomienie testów jednostkowych.
Comment[pt]=Permite-lhe ver e executar testes unitários.
Comment[pt_BR]=Permite-lhe ver e executar testes unitários.
Comment[ru]=Позволяет просматривать и запускать модульные тесты.
Comment[sk]=Umožní vám vidieť a spustiť unit testy.
Comment[sl]=Omogoča ogled in zagon preizkusov enot.
Comment[sv]=Låter dig titta på och köra enhetstester.
Comment[tr]=Birim testlerini görmenizi ve çalıştırmanızı sağlar.
Comment[uk]=Надає вам змогу переглядати і виконувати перевірки модулів.
Comment[x-test]=xxLets you see and run unit tests.xx
Comment[zh_CN]=让您查看并运行单元测试。
Comment[zh_TW]=讓您查看並執行單元測試。
Name=Unit Test View
Name[bs]=Pogled testa jedinica
Name[ca]=Vista de proves unitàries
Name[ca@valencia]=Vista de proves unitàries
Name[da]=Enhedstest-visning
Name[de]=Unittest-Ansicht
Name[el]=Προβολή unit test
Name[en_GB]=Unit Test View
Name[es]=Vista de la prueba unitaria
Name[et]=Ühiktestide vaade
Name[fi]=Yksikkötestinäkymä
Name[fr]=Affichage des tests unitaires
Name[gl]=Vista de probas unitarias
Name[hu]=Egységteszt nézet
Name[it]=Vista test d'unità
Name[kk]=Модульді сынау көрінісі
Name[nb]=Enhetstest-visning
Name[nl]=Weergave van test van eenheid
Name[pl]=Widok jednostkowego testu
Name[pt]=Área de Testes Unitários
Name[pt_BR]=Exibição de testes unitários
Name[ru]=Панель модульных тестов
Name[sk]=Pohľad unit testov
Name[sl]=Prikaz preizkusov enot
Name[sv]=Visning av enhetstester
Name[tr]=Birim Test Görünümü
Name[uk]=Перегляд перевірок модулів
Name[x-test]=xxUnit Test Viewxx
Name[zh_CN]=单元测试视图
Name[zh_TW]=單元測試檢視
GenericName=Unit Test View
GenericName[bs]=Pogled testa jedinica
GenericName[ca]=Vista de proves unitàries
GenericName[ca@valencia]=Vista de proves unitàries
GenericName[da]=Enhedstest-visning
GenericName[de]=Unittest-Ansicht
GenericName[el]=Προβολή unit test
GenericName[en_GB]=Unit Test View
GenericName[es]=Vista de la prueba unitaria
GenericName[et]=Ühiktestide vaade
GenericName[fi]=Yksikkötestinäkymä
GenericName[fr]=Affichage des tests unitaires
GenericName[gl]=Vista de probas unitarias
GenericName[hu]=Egységteszt nézet
GenericName[it]=Vista test d'unità
GenericName[kk]=Модульді сынау көрінісі
GenericName[nb]=Enhetstest-visning
GenericName[nl]=Weergave van test van eenheid
GenericName[pl]=Widok jednostkowego testu
GenericName[pt]=Área de Testes Unitários
GenericName[pt_BR]=Exibição de testes unitários
GenericName[ru]=Панель модульных тестов
GenericName[sk]=Pohľad unit testov
GenericName[sl]=Prikaz preizkusov enot
GenericName[sv]=Visning av enhetstester
GenericName[tr]=Birim Test Görünümü
GenericName[uk]=Перегляд перевірок модулів
GenericName[x-test]=xxUnit Test Viewxx
GenericName[zh_CN]=单元测试视图
GenericName[zh_TW]=單元測試檢視
Icon=preflight-verifier
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevtestview
X-KDE-PluginInfo-Name=kdevtestview
X-KDE-PluginInfo-Author=Miha Čančula
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Testing
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI
